<?php
// vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker:
/**
 * Base para pgina con multiples subpginas al capturar caso
 *
 * PHP version 5
 *
 * @category  SIVeL
 * @package   SIVeL
 * @author    Vladimir Tmara <vtamara@pasosdeJesus.org>
 * @copyright 2005 Dominio pblico. Sin garantas.
 * @license   http://creativecommons.org/licenses/publicdomain/ Dominio Pblico. Sin garantas.
 * @version   $Id: PagBaseMultiple.php,v 1.20 2009/06/23 14:22:37 vtamara Exp $
 * @link      http://sivel.sf.net
 */

/**
 * Base para pgina con multiples subpginas al capturar caso
 */
require_once 'PagBaseSimple.php';
require_once 'HTML/QuickForm/Action.php';

/** 
 * Accin que responde al botn eliminar.
 *
 * @category SIVeL
 * @package  SIVeL
 * @author   Vladimir Tmara <vtamara@pasosdeJesus.org>
 * @license  http://creativecommons.org/licenses/publicdomain/ Dominio Pblico.
 * @link     http://sivel.sf.net/tec
 * @see BuscarId
 */
class EliminarMultiple extends HTML_QuickForm_Action
{
    /** 
     * Ejecuta accin
     *
     * @param object &$page      Pgina
     * @param string $actionName Accin
     *
     * @return void
     */
    function perform(&$page, $actionName)
    {
        $page->elimina($page->_submitValues);
        if ($_SESSION[$page->pref.'_pag'] >= $_SESSION[$page->pref.'_total']) {
            $_SESSION[$page->pref.'_pag'] = 
                max($_SESSION[$page->pref.'_total']-1, 0);
        }
        $page->nullVar();
        $page->_submitValues = array();
        $page->_defaultValues = array();
        $page->handle('display'); 
    }
}

/** 
 * Accin que responde al botn nuevo 
 *
 * @category SIVeL
 * @package  SIVeL
 * @author   Vladimir Tmara <vtamara@pasosdeJesus.org>
 * @license  http://creativecommons.org/licenses/publicdomain/ Dominio Pblico.
 * @link     http://sivel.sf.net/tec
 * @see BuscarId
 */
class NuevoMultiple extends HTML_QuickForm_Action
{
    /** 
     * Ejecuta accin
     *
     * @param object &$page      Pgina
     * @param string $actionName Accin
     *
     * @return void
     */
    function perform(&$page, $actionName)
    {
        if ($page->procesa($page->_submitValues)) {
            $page->_submitValues = array();
            $page->_defaultValues = array();
            $page->nullVar();
            $_SESSION[$page->pref.'_pag'] = $_SESSION[$page->pref.'_total'];
        }
        $page->handle('display');
    }
}

/** 
 * Accin que responde al botn nuevo como copia 
 *
 * @category SIVeL
 * @package  SIVeL
 * @author   Vladimir Tmara <vtamara@pasosdeJesus.org>
 * @license  http://creativecommons.org/licenses/publicdomain/ Dominio Pblico.
 * @link     http://sivel.sf.net/tec
 * @see BuscarId
 */
class NuevoCopiaMultiple extends HTML_QuickForm_Action
{
    /** 
     * Ejecuta accin
     *
     * @param object &$page      Pgina
     * @param string $actionName Accin
     *
     * @return void
     */
    function perform(&$page, $actionName)
    {
        if ($page->procesa($page->_submitValues)) {
            $page->_submitValues = array();
            $page->_defaultValues = array();
            $page->iniVar();
            $_SESSION['nuevo_copia_id'] = $page->copiaId();
            $page->nullVar();
            $_SESSION[$page->pref.'_pag'] = $_SESSION[$page->pref.'_total'];
        }
        $page->handle('display');
    }
}


/** 
 * Accin que responde al botn anterior 
 *
 * @category SIVeL
 * @package  SIVeL
 * @author   Vladimir Tmara <vtamara@pasosdeJesus.org>
 * @license  http://creativecommons.org/licenses/publicdomain/ Dominio Pblico.
 * @link     http://sivel.sf.net/tec
 * @see BuscarId
 */
class AnteriorMultiple extends HTML_QuickForm_Action
{
    /** 
     * Ejecuta accin
     *
     * @param object &$page      Pgina
     * @param string $actionName Accin
     *
     * @return void
     */
    function perform(&$page, $actionName)
    {
        if ($page->procesa($page->_submitValues)) {
            $page->_submitValues = array();
            $page->_defaultValues = array();
            if ($_SESSION[$page->pref.'_pag'] > 0) {
                $_SESSION[$page->pref.'_pag']--;
                $page->nullVar();
            }
        }
        $page->handle('display');
    }
}

/** 
 * Accin que responde al botn siguiente 
 *
 * @category SIVeL
 * @package  SIVeL
 * @author   Vladimir Tmara <vtamara@pasosdeJesus.org>
 * @license  http://creativecommons.org/licenses/publicdomain/ Dominio Pblico.
 * @link     http://sivel.sf.net/tec
 * @see BuscarId
 */
class SiguienteMultiple extends HTML_QuickForm_Action
{
    
    /** 
     * Ejecuta accin
     *
     * @param object &$page      Pgina
     * @param string $actionName Accin
     *
     * @return void
     */
    function perform(&$page, $actionName)
    {
        if ($page->procesa($page->_submitValues)) {
            $page->_submitValues = array();
            $page->_defaultValues = array();
            if ($_SESSION[$page->pref.'_pag'] < 
                $_SESSION[$page->pref.'_total']) {
                $_SESSION[$page->pref.'_pag']++;
            }
        }
        $page->nullVar();
        $page->handle('display');
    }
}


/**
 * Clase base para pgina con multiples subpginas al capturar caso.
 *
 * La dea es identificar con un nmero las posibles subpginas, para
 * poder avanzar, retroceder, eliminar y agregar nuevos.
 * La informacin de la subpgina en la que est se mantiene en variables
 * de sesin que tienen un prefijo comn.
 *
 * Ver tambin documentacin de clase base.
 *
 * @category SIVeL
 * @package  SIVeL
 * @author   Vladimir Tmara <vtamara@pasosdeJesus.org>
 * @license  http://creativecommons.org/licenses/publicdomain/ Dominio Pblico.
 * @link     http://sivel.sf.net/tec
 * @see PagBaseSimple
 */
abstract class PagBaseMultiple extends PagBaseSimple
{

    /** Titulo corto que aparece en botones */
    var $tcorto = '';

    /** Prefijo comn para variables de sesin de la clase */
    var $pref = '';
   
    /** Habilitar boton Nueva Copia */
    var $nuevoCopia; 

    /** 
     * Pone en null variables asociadas a tablas de la pestaa.
     *
     * @return null
     */
    abstract function nullVar();

    /** 
     * Elimina de base de datos el registro actual.
     *
     * @param array &$valores Valores enviados por formulario.
     *
     * @return null
     */
    abstract function elimina(&$valores) ;

    /** 
     * Retorna una identificacin del registro actual. 
     *
     * @return string Identifacin
     */
    abstract function copiaId();

    /**
     * Constructora
     *
     * @param string $nomForma     Nombre del formulario
     * @param string $mreq         Mensaje de informacin faltante
     * @param string $titulo       Ttulo 
     * @param string $tcorto       Ttulo corto (para tabulador)
     * @param string $pref         Prefijo comn para variables de sesin
     * @param string $clase_modelo Clase tpica de esta pgina
     * @param bool   $nuevoCopia   Indica si se habilita botn "Nueva Copia"
     *
     * @return null
     */
    function PagBaseMultiple($nomForma, $mreq, $titulo, $tcorto,
        $pref, $clase_modelo, $nuevoCopia = true)
    {
        parent::PagBaseSimple($nomForma, $mreq, $titulo);
        $this->tcorto = $tcorto;
        $this->pref = $pref;
        $this->clase_modelo = $clase_modelo;
        $this->nuevoCopia = $nuevoCopia;

        $this->addAction('eliminar', new EliminarMultiple());
        $this->addAction('nuevo', new NuevoMultiple());
        if ($nuevoCopia) {
            $this->addAction('nuevoCopia', new NuevoCopiaMultiple());
        }
        $this->addAction('anteriorMultiple', new AnteriorMultiple());
        $this->addAction('siguienteMultiple', new SiguienteMultiple());

        if (!isset($_SESSION[$pref . '_pag'])) {
            $_SESSION[$pref . '_pag'] = 0;
        }   
    }


    /** 
     * Construye elementos del formulario incluyendo botones 
     * (anterior/siguiente/eliminar/nuevo/nueva copia)
     *
     * @return Formulario
     */
    function buildForm()
    {
        $this->_formBuilt = true;
        $this->_submitValues = array();
        $this->_defaultValues = array();

        $cm = "b" . $this->clase_modelo;
        if (!isset($this->$cm) || $this->$cm == null) {
            $db = $this->iniVar();
        } else {
            $db = $this->$cm->_do->getDatabaseConnection();
        }
        $this->controller->creaTabuladores($this, array('class' => 'flat'));
        $idcaso =& $_SESSION['basicos_id'];
        if (!isset($idcaso) || $idcaso == null) {
           die("Bug: idcaso no debera ser null");
        }
    
        $comp = $idcaso == $GLOBALS['idbus'] ? 'Consulta' : 'Caso ' . $idcaso; 
        $nf = $_SESSION[$this->pref.'_pag'] >= $_SESSION[$this->pref.'_total'] ?
            '-' : $_SESSION[$this->pref . '_pag'] + 1;
        $e =& $this->addElement('header', null, '<table width = "100%">' .
            '<th align = "left">' . $this->titulo . ' (' .
            $nf .'/' . $_SESSION[$this->pref . '_total'] .
            ')</th><th algin = "right">' .
            $comp . "</th></table>");
   
        $this->formularioAgrega($db, $idcaso); 

        $nac = 'eliminar';
        $n = $this->getButtonName($nac);
        $e =& $this->createElement('submit', $n, 'Eliminar');
        $ed[] =& $e;
    
        $nac = 'nuevo';
        $n = $this->getButtonName($nac);
        $e =& $this->createElement('submit', $n, 'Nueva');
        $ed[] =& $e;
        if ($cm == 'bfuente_directa_caso' && isset($_SESSION['forma_modo']) 
            && $_SESSION['forma_modo'] == 'busqueda') {
            $e->updateAttributes(array('disabled' => true));
        }
 
        $nac = 'nuevoCopia';
        $n = $this->getButtonName($nac);
        $e =& $this->createElement('submit', $n, 'Nueva Copia');
        if (!$this->nuevoCopia) { 
            $e->updateAttributes(array('disabled' => 'true'));
        } 
        $ed[] =& $e;
        if ($cm == 'bfuente_directa_caso' && isset($_SESSION['forma_modo']) 
            && $_SESSION['forma_modo'] == 'busqueda') {
            $e->updateAttributes(array('disabled' => true));
        }
 
        $nac = 'anteriorMultiple';
        $n = $this->getButtonName($nac);
        $e =& $this->createElement('submit', $n, $this->tcorto.' anterior');
        $ed[] =& $e;
        if ($cm == 'bfuente_directa_caso' && isset($_SESSION['forma_modo']) 
            && $_SESSION['forma_modo'] == 'busqueda') {
            $e->updateAttributes(array('disabled' => true));
        }
    
        $nac = 'siguienteMultiple';
        $n = $this->getButtonName($nac);
        $e =& $this->createElement('submit', $n, $this->tcorto.' siguiente');
        $ed[] =& $e;
        if ($cm == 'bfuente_directa_caso' && isset($_SESSION['forma_modo']) 
            && $_SESSION['forma_modo'] == 'busqueda') {
            $e->updateAttributes(array('disabled' => true));
        }
        
        $this->addGroup($ed, null, '', '&nbsp;', false);
        $this->controller->creaBotonesEstandar($this);
    
        $this->setDefaultAction('siguiente');

        $this->formularioValores($db, $idcaso); 
    }

}

?>
