<?php
// vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker:
/**
 * Pgina del multi-formulario para capturar caso (captura_caso.php). 
 *
 * PHP version 5
 *
 * @category  SIVeL
 * @package   SIVeL
 * @author    Vladimir Tmara <vtamara@pasosdeJesus.org>
 * @copyright 2004 Dominio pblico. Sin garantas.
 * @license   http://creativecommons.org/licenses/publicdomain/ Dominio Pblico. Sin garantas.
 * @version   $Id: PagFuentesFrecuentes.php,v 1.49.4.2 2010/03/20 15:01:12 vtamara Exp $
 * @link      http://sivel.sf.net
 */

/**
 * Pestaa Fuentes Frecuentes del multi-formulario capturar caso 
 */

require_once 'PagBaseMultiple.php';
require_once 'Prensa.php';

/**
 * Pgina fuentes frecuentes.
 * Ver documentacin de funciones en clase base.
 *
 * @category SIVeL
 * @package  SIVeL
 * @author   Vladimir Tmara <vtamara@pasosdeJesus.org>
 * @license  http://creativecommons.org/licenses/publicdomain/ Dominio Pblico.
 * @link     http://sivel.sf.net/tec
 * @see PagBaseMultiple
 */
class PagFuentesFrecuentes extends PagBaseMultiple
{

    /** Fuente frecuente asociada al caso, que se est consultando */
    var $bescrito_caso;

    var $titulo = 'Fuentes Frecuentes';

    var $tcorto = 'Fuente';

    var $pref = "ff";

    var $nuevaCopia = false;

    var $clase_modelo = 'escrito_caso';
    
    /**
     * Pone en null variables asociadas a tablas de la pestaa.
     *
     * @return null
     */
    function nullVar()
    {
        $this->bescrito_caso = null;
    }

    /** 
     * Retorna una identificacin del registro actual. 
     *
     * @return string Identifacin
     */
    function copiaId()
    {
        $r = $this->bescrito_caso->_do->id_caso.":" .
            $this->bescrito_caso->_do->id_prensa.":" .
            $this->bescrito_caso->_do->fecha;
        return  $r;
    }


     /** 
     * Elimina de base de datos el registro actual.
     *
     * @param array &$valores Valores enviados por formulario.
     *
     * @return null
     */
    function elimina(&$valores)
    {
        $this->iniVar();
        if ($this->bescrito_caso->_do->id_prensa != null) {
            $this->bescrito_caso->_do->delete();
            $_SESSION['ff_total']--;
        }
    }

    /**
     * Inicializa variables y datos de la pestaa.
     * Ver documentacin completa en clase base.
     *
     * @return handle Conexin a base de datos
     */
     function iniVar()
    {
        $do =& DB_DataObject::factory('escrito_caso');
        $db =& $do->getDatabaseConnection();
        $idcaso =& $_SESSION['basicos_id'];
        if (!isset($idcaso) || $idcaso == null) {
            die("Bug: idcaso no debera ser null");
        } 
        $do->id_caso = $idcaso;
        $result = $db->query("SELECT id_prensa from escrito_caso, prensa " .
            "WHERE id_caso='$idcaso' AND id_prensa=id " .
            "ORDER BY nombre;");
        $row = array();
        $idp = array();
        $tot = 0;
        while ($result->fetchInto($row)) {
            $idp[] = $row[0];
            $tot++;
        }
        $_SESSION['ff_total'] = $tot;
        if ($_SESSION['ff_pag'] < 0 || $_SESSION['ff_pag'] >= $tot) {
            $do->id_prensa = null;
        } else {
            $do->id_prensa = $idp[$_SESSION['ff_pag']];
            $do->find();
            $do->fetch();
        }

        $this->bescrito_caso =& DB_DataObject_FormBuilder::create($do,
            array('requiredRuleMessage' => $GLOBALS['mreglareq'],
                  'ruleViolationMessage' => $GLOBALS['mreglavio'] )); 
        return $db;
    }


    /**
     * Constructora.
     * Ver documentacin completa en clase base.
     *
     * @param string $nomForma Nombre 
     * @param string $mreq     Mensaje de dato requerido
     *
     * @return void
     */
    function PagFuentesFrecuentes($nomForma, $mreq)
    {
        parent::PagBaseMultiple($nomForma, $mreq, 'Fuentes Frecuentes',
            'Fuente', 'ff', 'escrito_caso');

        $this->addAction('siguiente', new Siguiente());
        $this->addAction('anterior', new Anterior());
    }

    
    /**
     * Agrega elementos al formulario.
     * Ver documentacin completa en clase base.
     *
     * @param handle &$db    Conexin a base de datos
     * @param string $idcaso Id del caso
     *
     * @return void
     *
     * @see PagBaseSimple
     */
    function formularioAgrega(&$db, $idcaso)
    {
        $GLOBALS['fechaPuedeSerVacia'] = isset($_SESSION['forma_modo']) 
            && $_SESSION['forma_modo'] == 'busqueda';

        $this->bescrito_caso->createSubmit = 0;
        $this->bescrito_caso->useForm($this);
        $this->bescrito_caso->getForm();

        $this->registerRule('frecuenteposterior', 'function', 'frecposterior',
            'PagFuentesFrecuentes');
        $this->addRule('fecha', 
            'La fecha de la fuente debe ser posterior a la del caso',
            'frecuenteposterior', null, 'client');

        $_SESSION['sin_csrf'] = mt_rand(0, 1000);
        $this->addElement('hidden', 'evita_csrf', $_SESSION['sin_csrf']);
    }


    /**
     * Llena valores del formulario.  
     * Ver documentacin completa en clase base.
     *
     * @param handle  &$db    Conexin a base de datos
     * @param integer $idcaso Id del caso
     *
     * @return void
     * @see PagBaseSimple
     */
    function formularioValores(&$db, $idcaso)
    {

        if (isset($_SESSION['recuperaErrorValida'])) {
            formularioValoresEstablece($this, 
                $this->bescrito_caso->_do->fb_fieldsToRender,
                $_SESSION['recuperaErrorValida']);
            unset($_SESSION['recuperaErrorValida']);
        } else {
            foreach ($this->bescrito_caso->_do->fb_fieldsToRender as $c) {
                $cq = $this->getElement($c);
                if (isset($this->bescrito_caso->_do->$c)) {
                    $cq->setValue($this->bescrito_caso->_do->$c);
                }
            }
        }
        if (isset($_SESSION['forma_modo']) 
            && $_SESSION['forma_modo'] == 'busqueda') {
            $f = $this->getElement('fecha');
            $da = $f->getValue();
            if ($da['Y'][0] == ($GLOBALS['anio_min'] - 1)) {
                $f->setValue(array('d' => array('0' => ''),
                    'm' => array('0' => ''),
                    'Y' => array('0' => ''))); 
            }
        }


        if (isset($_SESSION['nuevo_copia_id']) && 
            strstr($_SESSION['nuevo_copia_id'], ":") != false) {
            list($idc, $idp, $fecha) = 
                explode(':', $_SESSION['nuevo_copia_id']);
            unset($_SESSION['nuevo_copia_id']);
            $d =& DB_DataObject::factory('escrito_caso');
            $d->id_caso = $idc;
            $d->id_prensa = $idp;
            $d->fecha = $fecha;
            $d->find();
            $d->fetch();
            foreach ($d->fb_fieldsToRender as $c) {
                $cq = $this->getElement($c); 
                $cq->setValue($d->$c);
            }
        }

    }

    /**
     * Elimina registros de tablas relacionadas con caso de este formulario.
     * Ver documentacin completa en clase base.
     *
     * @param handle  &$db    Conexin a base de datos
     * @param integer $idcaso Id del caso
     *
     * @return void
     * @see PagBaseSimple
     */
    static function eliminaDep(&$db, $idcaso) 
    {
        assert($db != null);
        assert(isset($idcaso));
        $db->query("DELETE FROM escrito_caso WHERE id_caso='$idcaso'");
    }

    /**
     * Procesa valores del formulario enviados por el usuario.
     * Ver documentacin completa en clase base.
     *
     * @param handle &$valores Valores ingresados por usuario
     *
     * @return bool Verdadero si y solo si puede completarlo con xito
     * @see PagBaseSimple
     */
    function procesa(&$valores) 
    {
        $es_vacio = ($valores['id_prensa'] == null || 
                $valores['id_prensa'] == '') &&
            ($valores['ubicacion'] == null || $valores['ubicacion'] == '') &&
            ($valores['clasificacion'] == null || 
                $valores['clasificacion'] == '') &&
            ($valores['ubicacion_fisica'] == null || 
                $valores['ubicacion_fisica'] == '')
        ;

        if ($es_vacio) {
            return true;
        }
        if (!$this->validate()) {
            return false;
        }
        if (!isset($valores['evita_csrf']) || 
            $valores['evita_csrf'] != $_SESSION['sin_csrf']) {
            die("Datos enviados no pasaron verificacin CSRF (" .
                $_SESSION['sin_csrf'] . ", " . $valores['evita_csrf']  . ")");
        }

        $db = $this->iniVar();
        $do =& DB_DataObject::factory('caso');
        $do->id = $this->bescrito_caso->_do->id_caso;
        $do->find();
        $do->fetch();
        $df = call_user_func($this->bescrito_caso->dateToDatabaseCallback,
                       $valores['fecha']); 
        /* No funcionan reglas de validacin de QuickForm 
           porque no est construido el formulario cuando pasa
           por esta funcin.  $this->validate encuentra que
           $this->_rules es vacio */
        
        if ((!isset($_SESSION['forma_modo']) ||
            $_SESSION['forma_modo'] != 'busqueda') &&
            strtotime($df) < strtotime($do->fecha)) {
            errorValida('Fecha de fuente no puede ser anterior a la del caso',
                $valores);
            return false;
        }

        if ($this->bescrito_caso->_do->id_prensa != null) {
            $this->bescrito_caso->_do->delete();
            $_SESSION['ff_total']--;
        }
        $this->bescrito_caso->
            forceQueryType(DB_DATAOBJECT_FORMBUILDER_QUERY_FORCEINSERT);
        
        if (isset($_SESSION['forma_modo']) &&
            $_SESSION['forma_modo'] == 'busqueda' &&
            isset($valores['id_caso']) && 
            $valores['id_caso'] == $GLOBALS['idbus']) {
            $oc = $this->bescrito_caso->_do;
            if ($oc->find() == 0) {
                $vp = $valores['id_prensa'] == '' ?
                    DataObjects_Prensa::id_sininfo() : $valores['id_prensa'];
                $fp = $df == '0000-00-00' ? 
                    ($GLOBALS['anio_min'] - 1) . "-01-01" :
                    $df;
                $q = "INSERT INTO escrito_caso (fecha, ubicacion, " .
                    "clasificacion, ubicacion_fisica, id_prensa, id_caso) " .
                    "VALUES ('" . $fp . "', " .
                    "'', '', '', '" . $vp .
                    "', '" . $GLOBALS['idbus'] . "');";
                //echo "OJO $q";
                $res = $db->query($q);
                if (PEAR::isError($res)) {
                    die($res->getMessage() . " - " . $res->getUserInfo());
                }
                $this->bescrito_caso->
                    forceQueryType(DB_DATAOBJECT_FORMBUILDER_QUERY_FORCEUPDATE);
            }
            if ($df == "0000-00-00" || 
                $valores['fecha']['Y'] == $GLOBALS['anio_min']) {
                //print_r($valores['fecha']);
                $valores['fecha']['d'] = 1;
                $valores['fecha']['m'] = 1;
                $valores['fecha']['Y'] = $GLOBALS['anio_min'] - 1;
            }
            if ($valores['id_prensa'] == '') {
                $valores['id_prensa'] = DataObjects_Prensa::id_sinInfo();
            }
        } 

        $ret = $this->process(array(&$this->bescrito_caso, 'processForm'), false);
        $_SESSION['ff_total']++;
//        die("x");

        $this->bescrito_caso = null;
        funcionario_caso($_SESSION['basicos_id']);
        return  $ret;
    }



    /**
     * Prepara consulta SQL para buscar datos de este formulario.
     * Ver documentacin completa en clase base.
     *
     * @param string &$w       Consulta que se construye
     * @param string &$t       Tablas
     * @param object &$dCaso   Objeto con caso
     * @param string &$subcons Subconsulta
     *
     * @return void
     * @see PagBaseSimple
     */
    function datosBusqueda(&$w, &$t, &$dCaso, &$subcons) 
    {
        datosBusquedaGen($w, $t, $dCaso->id, 
            'escrito_caso', 'Prensa', 'id_prensa', false);
//        echo "OJO w=$w";
    }



}

?>
